@@ -79,8 +79,9 @@
      tREG = 295,
      NEG = 296,
      MED = 297,
-     POS = 298,
-     HIGH = 299
+     LNEG = 298,
+     POS = 299,
+     HIGH = 300
    };
 #endif
 /* Tokens.  */
@@ -124,21 +125,22 @@
 #define tREG 295
 #define NEG 296
 #define MED 297
-#define POS 298
-#define HIGH 299
+#define LNEG 298
+#define POS 299
+#define HIGH 300
 
 
 
 
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
 typedef union YYSTYPE
-#line 37 "./ce_parser.y"
+#line 36 "./ce_parser.y"
 {
   int int_t[MP_SIZE];
   int integer;
 }
 /* Line 1489 of yacc.c.  */
-#line 142 "ce_parser.tab.h"
+#line 144 "ce_parser.tab.h"
 	YYSTYPE;
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
